==> sms-service-1.8.0-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgTrackerImpl.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import java.io.IOException;

import org.opennms.protocols.rt.Messenger;
import org.opennms.protocols.rt.RequestTracker;
import org.smslib.OutboundMessage;
import org.smslib.USSDRequest;
import org.springframework.beans.factory.InitializingBean;

/**
 * MobileMsgTracker
 *
 * @author brozow
 */
public class MobileMsgTrackerImpl extends RequestTracker<MobileMsgRequest, MobileMsgResponse> implements MobileMsgTracker, InitializingBean {

    public MobileMsgTrackerImpl(String name,  Messenger<MobileMsgRequest, MobileMsgResponse> messenger)
            throws IOException {
        super(name, messenger, new MatchingRequestLocator());

    }
    
    
    public MobileMsgRequest sendSmsRequest(OutboundMessage msg, long timeout, int retries, MobileMsgResponseCallback cb, MobileMsgResponseMatcher matcher) throws Exception {
        SmsRequest request = new SmsRequest(msg, timeout, retries, cb, matcher);
        sendRequest(request);
        return request;
    }

    public MobileMsgRequest sendUssdRequest(USSDRequest msg, long timeout, int retries, MobileMsgResponseCallback cb, MobileMsgResponseMatcher matcher) throws Exception {
        UssdRequest request = new UssdRequest(msg, timeout, retries, cb, matcher);
        sendRequest(request);
        return request;
    }


    public void afterPropertiesSet() throws Exception {
        start();
    }

}

==> sms-service-1.8.6-sources.jar: org/opennms/sms/reflector/smsservice/MobileMsgTrackerImpl.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.sms.reflector.smsservice;

import java.io.IOException;

import org.opennms.protocols.rt.Messenger;
import org.opennms.protocols.rt.RequestTracker;
import org.smslib.OutboundMessage;
import org.smslib.USSDRequest;
import org.springframework.beans.factory.InitializingBean;

/**
 * MobileMsgTracker
 *
 * @author brozow
 * @version $Id: $
 */
public class MobileMsgTrackerImpl extends RequestTracker<MobileMsgRequest, MobileMsgResponse> implements MobileMsgTracker, InitializingBean {

    /**
     * <p>Constructor for MobileMsgTrackerImpl.</p>
     *
     * @param name a {@link java.lang.String} object.
     * @param messenger a {@link org.opennms.protocols.rt.Messenger} object.
     * @throws java.io.IOException if any.
     */
    public MobileMsgTrackerImpl(String name,  Messenger<MobileMsgRequest, MobileMsgResponse> messenger)
            throws IOException {
        super(name, messenger, new MatchingRequestLocator());

    }
    
    
    /** {@inheritDoc} */
    public MobileMsgRequest sendSmsRequest(OutboundMessage msg, long timeout, int retries, MobileMsgResponseCallback cb, MobileMsgResponseMatcher matcher) throws Exception {
        SmsRequest request = new SmsRequest(msg, timeout, retries, cb, matcher);
        sendRequest(request);
        return request;
    }

    /** {@inheritDoc} */
    public MobileMsgRequest sendUssdRequest(USSDRequest msg, long timeout, int retries, MobileMsgResponseCallback cb, MobileMsgResponseMatcher matcher) throws Exception {
        UssdRequest request = new UssdRequest(msg, timeout, retries, cb, matcher);
        sendRequest(request);
        return request;
    }


    /**
     * <p>afterPropertiesSet</p>
     *
     * @throws java.lang.Exception if any.
     */
    public void afterPropertiesSet() throws Exception {
        start();
    }

}
